
# Slot: node_type_list_support_balanced_quotes


Whether to support balanced quotes.

URI: [https://w3id.org/neat/ensmallenRunConfig__node_type_list_support_balanced_quotes](https://w3id.org/neat/ensmallenRunConfig__node_type_list_support_balanced_quotes)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
